use Perl6::Form;

warn "\n";
warn "[>>>>>>.<<<]\n";
warn < form '[{>>{10.3}>>.<<}]', 1.2345678;
warn < form '[{>>>>.<{10.3}<}]', 1.2345678;

warn "\n";
warn      "[>>>>>>>>>.<<<<<<<<<]\n";
warn < form '[{>(20.10).<<<<<<<<<}]', 1.23456789;
warn < form '[{(20.10)>.<<<<<<<<<}]', 1.23456789;
warn < form '[{>>>>>>>>.(20.10)<<}]', 1.23456789;
warn < form '[{>>>>>>>>.<(20.10)<}]', 1.23456789;
warn < form '[{>>>>>>>>.<<(20.10)}]', 1.23456789;

warn "\n";
warn      "[>>>>>>>>>>.<<<<<<<]\n";
warn < form '[{>>>>>>>>>.(18.7)}]', 1.23456789;

warn "\n";
warn      "[.<<<<<<<<<<]\n";
warn < form '[{>>{11.10}>.<<<<<}]', 1.2345678901;
warn < form '[{>>{11.10}>.<<<<<}]', 0.2345678901;
warn < form '[{>>{11.10}>.<<<<<}]', 0.234567891;

warn "\n";
warn      "[>>>>><<<<<]\n";
warn < form '[{||(10)||}]', "oops!";

warn "\n";
warn      "[>>>>>>>>>>>>>>>>>>>>>>>>><<<<<<<<<<<<<<<<<<<<<<<<<]\n";
warn < form '[{||||||{50+}||}]', "oops!";
warn < form '[{||||||{50+}||}]', "oops!"x50;

warn "\nErrors:\n";
try { warn < form '[{>>{11}>.<<<{10}<<}]', 1.2345678901 } || warn $^OS_ERROR; 
try { warn < form '[{|||(10)|||}]', "oops!" } || warn $^OS_ERROR;

try { warn < form '[{>(19.10).<<<<<<<<<}]', "1.23456789!" } || warn $^OS_ERROR;

try { warn < form '[{>>>>>>>.<(9.10)<<}]', "1.23456789!" } || warn $^OS_ERROR;

try { warn < form '[{>>>>>>>>.<(10.10)<}]', "1.23456789!" } || warn $^OS_ERROR;

try { warn < form '[{>>{9.10}>>.<<<<<}]', "1.23456789!" } || warn $^OS_ERROR;

try { warn < form '[{>>>>.<<<{10.10}<<}]', "1.23456789!" } || warn $^OS_ERROR;
